==> jetjob_1.6.0.0.tar.gz: jetjob_1.6.0.0/htdocs/rsvn_main.php <==
<?php
//==============================================================
// Program Name		: ͽե졼ʬ
// File Name		: rsvn_main.php
//--------------------------------------------------------------
// Date             : 2002/02/26
// Author           : Satoshi Fujii
//--------------------------------------------------------------
// Note				: 
//                  : 
//--------------------------------------------------------------
// Rev.             : 
//                  : 
//==============================================================

require("jetjob.inc");
require("common_login.php");			// 
require("common_menu_change.inc");		// ˥塼


// ɽ
define("SEL_DAY",   "D");		// ɽ
define("SEL_WEEK",  "W");		// ɽʽ
define("SEL_MONTH", "M");		// ɽʷ


//==============================================================
// Function Name    : Program_Start
//--------------------------------------------------------------
// Note		        : 
//                  :
//==============================================================

Login_Start($PHP_SELF);
menu_change(PG_NAME(), $JJ_USERNAME);

// եѥ᡼ʤк
if (!isset($hiduke))
	$hiduke = date("Y-m-d");

if (!isset($sel))
	$sel = SEL_DAY;

print("<html>\n");
print("<head>\n");
print("<META http-equiv=\"Content-Language\" content=\"ja\">\n");
printf("<META http-equiv=\"Content-Type\" content=\"text/html;charset=%s\">\n", $JJ_OUTPUT_CHARSET);
printf("<LINK REL=\"STYLESHEET\" TYPE=\"text/css\" HREF=\"%s%s\">\n", $JJ_CSS_ROOT, $JJ_CSS_NAME);
print("</head>\n");
print("<frameset cols=\"180,*\">\n");
printf("<frame src=\"rsvn_submenu.php?hiduke=%s&sel=%s\" name=\"submenu\">\n", $hiduke, $sel);
printf("<frame src=\"rsvn_content.php?hiduke=%s&sel=%s\" name=\"content\">\n", $hiduke, $sel);
print("</frameset>\n");
print("</html>\n");

?>

==> jetjob_1.6.0.3.tar.gz: jetjob_1.6.0.3/htdocs/rsvn_main.php <==
<?php
//==============================================================
// Program Name		: ͽե졼ʬ
// File Name		: rsvn_main.php
//--------------------------------------------------------------
// Date             : 2002/02/26
// Author           : Satoshi Fujii
//--------------------------------------------------------------
// Note				: 
//                  : 
//--------------------------------------------------------------
// Rev.             : 
//                  : 
//==============================================================

require("jetjob.inc.php");
require("common_login.php");			// 
require("common_menu_change.inc");		// ˥塼


// ɽ
define("SEL_DAY",   "D");		// ɽ
define("SEL_WEEK",  "W");		// ɽʽ
define("SEL_MONTH", "M");		// ɽʷ


//==============================================================
// Function Name    : Program_Start
//--------------------------------------------------------------
// Note		        : 
//                  :
//==============================================================

Login_Start($PHP_SELF);
menu_change(PG_NAME(), $JJ_USERNAME);

// եѥ᡼ʤк
if (!isset($hiduke))
	$hiduke = date("Y-m-d");

if (!isset($sel))
	$sel = SEL_DAY;

print("<html>\n");
print("<head>\n");
print("<META http-equiv=\"Content-Language\" content=\"ja\">\n");
printf("<META http-equiv=\"Content-Type\" content=\"text/html;charset=%s\">\n", $JJ_OUTPUT_CHARSET);
printf("<LINK REL=\"STYLESHEET\" TYPE=\"text/css\" HREF=\"%s%s\">\n", $JJ_CSS_ROOT, $JJ_CSS_NAME);
print("</head>\n");
print("<frameset cols=\"180,*\">\n");
printf("<frame src=\"rsvn_submenu.php?hiduke=%s&sel=%s\" name=\"submenu\">\n", $hiduke, $sel);
printf("<frame src=\"rsvn_content.php?hiduke=%s&sel=%s\" name=\"content\">\n", $hiduke, $sel);
print("</frameset>\n");
print("</html>\n");

?>
